package org.jeecg.modules.adweb.common.util;

import java.time.ZoneId;
import java.util.*;

/**
 * AdWeb时间工具类
 *
 * <p>其它场景，参考 {@link org.jeecg.common.util.DateUtils}
 *
 * @author wfansh
 */
public class DateUtil {

    public static final ZoneId DEFAULT_ZONE_ID = ZoneId.of("Asia/Shanghai");

    /**
     * 特殊时间数据处理
     *
     * @param dateType 时间
     */
    public static Map<String, Date> dealDateType(String dateType) {
        Date now = new Date();
        Date start = null;
        Date end = null;
        if ("yesterday".equals(dateType)) {
            start = getTodayZeroTime(DateUtil.addDays(now, -1));
            end = getTodayZeroTime(now);
        }
        if ("today".equals(dateType)) {
            start = getTodayZeroTime(now);
            end = getTmrZeroTime(now);
        }
        if ("sevenDay".equals(dateType)) {
            end = getTmrZeroTime(now);
            start = addDays(end, -7);
        }
        if ("thirtyDay".equals(dateType)) {
            end = getTmrZeroTime(now);
            start = addDays(end, -30);
        }
        Map<String, Date> map = new HashMap<>();
        map.put("start", start);
        map.put("end", end);
        return map;
    }

    /**
     * 获取当日零点
     *
     * @param date
     * @return
     */
    public static Date getTodayZeroTime(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.HOUR_OF_DAY, 0);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        return calendar.getTime();
    }

    /**
     * 获取明日零点
     *
     * @param date
     * @return
     */
    public static Date getTmrZeroTime(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.HOUR_OF_DAY, 0);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        calendar.add(Calendar.DAY_OF_MONTH, 1);
        return calendar.getTime();
    }

    /**
     * 在当前日期上追加N天
     *
     * @param date 当前日期
     * @param num 添加天数
     * @return 日期字符串形式
     */
    public static Date addDays(Date date, int num) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        c.add(Calendar.DAY_OF_MONTH, num);
        return c.getTime();
    }
}
